// This file is auto-generated by @hey-api/openapi-ts

import type { CancelablePromise } from './core/CancelablePromise';
import { OpenAPI } from './core/OpenAPI';
import { request as __request } from './core/request';
import type { UserGetUserResponse, UserUpdateUserData, UserUpdateUserResponse, UserRegisterData, UserRegisterResponse, UserDeleteUserResponse, DashboardLoginAccessTokenData, DashboardLoginAccessTokenResponse, DashboardRegisterNewShopData, DashboardRegisterNewShopResponse, ShopLoginAccessTokenData, ShopLoginAccessTokenResponse, ShopDeleteUserData, ShopDeleteUserResponse, ShopLogoutResponse, ShopRegisterData, ShopRegisterResponse, ShopUpdateUserData, ShopUpdateUserResponse, UtilsHealthCheckResponse, UtilsTestDbResponse } from './types.gen';

export class DashboardService {
    /**
     * Get information about currently logged in user
     * @returns UserPublic Successful Response
     * @throws ApiError
     */
    public static userGetUser(): CancelablePromise<UserGetUserResponse> {
        return __request(OpenAPI, {
            method: 'GET',
            url: '/user'
        });
    }
    
    /**
     * Update user details
     * @param data The data for the request.
     * @param data.requestBody
     * @returns boolean Successful Response
     * @throws ApiError
     */
    public static userUpdateUser(data: UserUpdateUserData): CancelablePromise<UserUpdateUserResponse> {
        return __request(OpenAPI, {
            method: 'PUT',
            url: '/user',
            body: data.requestBody,
            mediaType: 'application/json',
            errors: {
                422: 'Validation Error'
            }
        });
    }
    
    /**
     * Register new user
     * @param data The data for the request.
     * @param data.requestBody
     * @returns boolean Successful Response
     * @throws ApiError
     */
    public static userRegister(data: UserRegisterData): CancelablePromise<UserRegisterResponse> {
        return __request(OpenAPI, {
            method: 'POST',
            url: '/user',
            body: data.requestBody,
            mediaType: 'application/json',
            errors: {
                422: 'Validation Error'
            }
        });
    }
    
    /**
     * Delete user
     * @returns boolean Successful Response
     * @throws ApiError
     */
    public static userDeleteUser(): CancelablePromise<UserDeleteUserResponse> {
        return __request(OpenAPI, {
            method: 'DELETE',
            url: '/user'
        });
    }
    
    /**
     * Login Access Token
     * OAuth2 compatible token login for the dashboard.
     *
     * This endpoint generates an access token required for authenticating future
     * requests to the dashboard section of the application. The token is valid for
     * a predefined expiration period.
     *
     * - **username**: User's email
     * - **password**: User's password
     *
     * **Note:** This login is restricted to dashboard access only and cannot be
     * used for tenant accounts access to shops
     * @param data The data for the request.
     * @param data.formData
     * @returns Token Successful Response
     * @throws ApiError
     */
    public static dashboardLoginAccessToken(data: DashboardLoginAccessTokenData): CancelablePromise<DashboardLoginAccessTokenResponse> {
        return __request(OpenAPI, {
            method: 'POST',
            url: '/login/access-token',
            formData: data.formData,
            mediaType: 'application/x-www-form-urlencoded',
            errors: {
                422: 'Validation Error'
            }
        });
    }
    
    /**
     * Register New Shop
     * @param data The data for the request.
     * @param data.requestBody
     * @returns boolean Successful Response
     * @throws ApiError
     */
    public static dashboardRegisterNewShop(data: DashboardRegisterNewShopData): CancelablePromise<DashboardRegisterNewShopResponse> {
        return __request(OpenAPI, {
            method: 'POST',
            url: '/shop',
            body: data.requestBody,
            mediaType: 'application/json',
            errors: {
                422: 'Validation Error'
            }
        });
    }
    
}

export class LoginService {
    /**
     * Login Access Token
     * OAuth2 compatible token login for the dashboard.
     *
     * This endpoint generates an access token required for authenticating future
     * requests to the dashboard section of the application. The token is valid for
     * a predefined expiration period.
     *
     * - **username**: User's email
     * - **password**: User's password
     *
     * **Note:** This login is restricted to dashboard access only and cannot be
     * used for tenant accounts access to shops
     * @param data The data for the request.
     * @param data.formData
     * @returns Token Successful Response
     * @throws ApiError
     */
    public static dashboardLoginAccessToken(data: DashboardLoginAccessTokenData): CancelablePromise<DashboardLoginAccessTokenResponse> {
        return __request(OpenAPI, {
            method: 'POST',
            url: '/login/access-token',
            formData: data.formData,
            mediaType: 'application/x-www-form-urlencoded',
            errors: {
                422: 'Validation Error'
            }
        });
    }
    
    /**
     * Login Access Token
     * OAuth2 compatible token login, get an access token for future requests
     * @param data The data for the request.
     * @param data.formData
     * @returns Token Successful Response
     * @throws ApiError
     */
    public static shopLoginAccessToken(data: ShopLoginAccessTokenData): CancelablePromise<ShopLoginAccessTokenResponse> {
        return __request(OpenAPI, {
            method: 'POST',
            url: '/shop/{shop_uuid}/login/access-token',
            formData: data.formData,
            mediaType: 'application/x-www-form-urlencoded',
            errors: {
                422: 'Validation Error'
            }
        });
    }
    
}

export class ShopService {
    /**
     * Login Access Token
     * OAuth2 compatible token login, get an access token for future requests
     * @param data The data for the request.
     * @param data.formData
     * @returns Token Successful Response
     * @throws ApiError
     */
    public static shopLoginAccessToken(data: ShopLoginAccessTokenData): CancelablePromise<ShopLoginAccessTokenResponse> {
        return __request(OpenAPI, {
            method: 'POST',
            url: '/shop/{shop_uuid}/login/access-token',
            formData: data.formData,
            mediaType: 'application/x-www-form-urlencoded',
            errors: {
                422: 'Validation Error'
            }
        });
    }
    
    /**
     * Delete user
     * @param data The data for the request.
     * @param data.shopUuid
     * @returns unknown Successful Response
     * @throws ApiError
     */
    public static shopDeleteUser(data: ShopDeleteUserData): CancelablePromise<ShopDeleteUserResponse> {
        return __request(OpenAPI, {
            method: 'DELETE',
            url: '/shop/{shop_uuid}/user/delete',
            path: {
                shop_uuid: data.shopUuid
            },
            errors: {
                422: 'Validation Error'
            }
        });
    }
    
    /**
     * User logout
     * @returns unknown Successful Response
     * @throws ApiError
     */
    public static shopLogout(): CancelablePromise<ShopLogoutResponse> {
        return __request(OpenAPI, {
            method: 'DELETE',
            url: '/shop/{shop_uuid}/user/logout'
        });
    }
    
    /**
     * Register new user
     * @param data The data for the request.
     * @param data.shopUuid
     * @param data.requestBody
     * @returns unknown Successful Response
     * @throws ApiError
     */
    public static shopRegister(data: ShopRegisterData): CancelablePromise<ShopRegisterResponse> {
        return __request(OpenAPI, {
            method: 'POST',
            url: '/shop/{shop_uuid}/user/register',
            path: {
                shop_uuid: data.shopUuid
            },
            body: data.requestBody,
            mediaType: 'application/json',
            errors: {
                422: 'Validation Error'
            }
        });
    }
    
    /**
     * Update user details
     * @param data The data for the request.
     * @param data.requestBody
     * @returns unknown Successful Response
     * @throws ApiError
     */
    public static shopUpdateUser(data: ShopUpdateUserData): CancelablePromise<ShopUpdateUserResponse> {
        return __request(OpenAPI, {
            method: 'PUT',
            url: '/shop/{shop_uuid}/user/update',
            body: data.requestBody,
            mediaType: 'application/json',
            errors: {
                422: 'Validation Error'
            }
        });
    }
    
}

export class UserService {
    /**
     * Get information about currently logged in user
     * @returns UserPublic Successful Response
     * @throws ApiError
     */
    public static userGetUser(): CancelablePromise<UserGetUserResponse> {
        return __request(OpenAPI, {
            method: 'GET',
            url: '/user'
        });
    }
    
    /**
     * Update user details
     * @param data The data for the request.
     * @param data.requestBody
     * @returns boolean Successful Response
     * @throws ApiError
     */
    public static userUpdateUser(data: UserUpdateUserData): CancelablePromise<UserUpdateUserResponse> {
        return __request(OpenAPI, {
            method: 'PUT',
            url: '/user',
            body: data.requestBody,
            mediaType: 'application/json',
            errors: {
                422: 'Validation Error'
            }
        });
    }
    
    /**
     * Register new user
     * @param data The data for the request.
     * @param data.requestBody
     * @returns boolean Successful Response
     * @throws ApiError
     */
    public static userRegister(data: UserRegisterData): CancelablePromise<UserRegisterResponse> {
        return __request(OpenAPI, {
            method: 'POST',
            url: '/user',
            body: data.requestBody,
            mediaType: 'application/json',
            errors: {
                422: 'Validation Error'
            }
        });
    }
    
    /**
     * Delete user
     * @returns boolean Successful Response
     * @throws ApiError
     */
    public static userDeleteUser(): CancelablePromise<UserDeleteUserResponse> {
        return __request(OpenAPI, {
            method: 'DELETE',
            url: '/user'
        });
    }
    
    /**
     * Delete user
     * @param data The data for the request.
     * @param data.shopUuid
     * @returns unknown Successful Response
     * @throws ApiError
     */
    public static shopDeleteUser(data: ShopDeleteUserData): CancelablePromise<ShopDeleteUserResponse> {
        return __request(OpenAPI, {
            method: 'DELETE',
            url: '/shop/{shop_uuid}/user/delete',
            path: {
                shop_uuid: data.shopUuid
            },
            errors: {
                422: 'Validation Error'
            }
        });
    }
    
    /**
     * User logout
     * @returns unknown Successful Response
     * @throws ApiError
     */
    public static shopLogout(): CancelablePromise<ShopLogoutResponse> {
        return __request(OpenAPI, {
            method: 'DELETE',
            url: '/shop/{shop_uuid}/user/logout'
        });
    }
    
    /**
     * Register new user
     * @param data The data for the request.
     * @param data.shopUuid
     * @param data.requestBody
     * @returns unknown Successful Response
     * @throws ApiError
     */
    public static shopRegister(data: ShopRegisterData): CancelablePromise<ShopRegisterResponse> {
        return __request(OpenAPI, {
            method: 'POST',
            url: '/shop/{shop_uuid}/user/register',
            path: {
                shop_uuid: data.shopUuid
            },
            body: data.requestBody,
            mediaType: 'application/json',
            errors: {
                422: 'Validation Error'
            }
        });
    }
    
    /**
     * Update user details
     * @param data The data for the request.
     * @param data.requestBody
     * @returns unknown Successful Response
     * @throws ApiError
     */
    public static shopUpdateUser(data: ShopUpdateUserData): CancelablePromise<ShopUpdateUserResponse> {
        return __request(OpenAPI, {
            method: 'PUT',
            url: '/shop/{shop_uuid}/user/update',
            body: data.requestBody,
            mediaType: 'application/json',
            errors: {
                422: 'Validation Error'
            }
        });
    }
    
}

export class UtilsService {
    /**
     * Health Check
     * Ping the API whether it's alive or not
     * @returns boolean Successful Response
     * @throws ApiError
     */
    public static utilsHealthCheck(): CancelablePromise<UtilsHealthCheckResponse> {
        return __request(OpenAPI, {
            method: 'GET',
            url: '/utils/health-check/'
        });
    }
    
    /**
     * Test Db
     * Ping database using select 1 to see if connection works
     * @returns boolean Successful Response
     * @throws ApiError
     */
    public static utilsTestDb(): CancelablePromise<UtilsTestDbResponse> {
        return __request(OpenAPI, {
            method: 'GET',
            url: '/utils/test-db/'
        });
    }
    
}